# @summary  Install and configure AFS
#
# @example Simple Example
#  include afs
#
# @example Use AFS Cache in Memory
#  class{'afs':
#    memcachesize => 524288,
#    options      => {
#      memcache => true,
#    },
#  }
#
# @param cachesize disk cache size
# @param memcachesize memorycachesize
# @param options
#  Hash of permissable TDB
# @param runserver run an afs server or not
# @param is_upstream Use upstream module
# @param prefer_upstream_dkms use dkms module
# @param aklog_unit
#  install and enable systemd user service aklog.service C8 and newer onlyw
# @param pam_afs_session
#  install and configure pam_afs_session in sshd pamstack. C8 and newer only.
# @param handle_cellservdb
#  let the module handle the client CellServDB files. On by default.
class afs (
  Variant[Enum['AUTOMATIC'], Pattern[/\A\d+\z/], Integer[0]] $cachesize = $afs::params::cachesize,
  Variant[Pattern[/\A\d+\z/], Integer[0]] $memcachesize                 = $afs::params::memcachesize,
  Hash $options                                                         = $afs::params::options,
  Enum['on','off'] $runserver                                           = $afs::params::runserver,
  String $thiscell                                                      = $afs::params::thiscell,
  Boolean $is_upstream                                                  = $afs::params::is_upstream,
  Boolean $prefer_upstream_dkms                                         = $afs::params::prefer_upstream_dkms,
  Boolean $enable_firewall                                              = $afs::params::enable_firewall,
  # Options only impacting C8 and newer.
  Boolean $aklog_unit                                                   = $afs::params::aklog_unit,
  Boolean $pam_afs_session                                              = $afs::params::pam_afs_session,
  Boolean $handle_cellservdb                                            = $afs::params::handle_cellservdb,
) inherits afs::params {

  contain afs::install
  contain afs::config
  contain afs::service

  Class[afs::install] -> Class[afs::config] -> Class[afs::service]

  if $enable_firewall {
    contain afs::firewall
  }
}
