# @summary Installs afs packages
# @api private
class afs::install(
  $is_upstream = $afs::is_upstream,
  $prefer_upstream_dkms = $afs::prefer_upstream_dkms,
  $pam_afs_session = $afs::pam_afs_session,
  $aklog_unit = $afs::aklog_unit,
) {

  $afs_kmod_pkg = $is_upstream ? {
    true => $prefer_upstream_dkms ? {
        true   => ['dkms-openafs'],
        false  => ['kmod-openafs'],
    },
    default => ["kernel-module-openafs-${::kernelrelease}", 'yum-kernel-module']
  }

  if versioncmp($facts['os']['release']['major'],'8') >= 0 {
    contain afs::kojitag
    $_afspkgs_require = 'Class[Afs::Kojitag]'
  } else {
    $_afspkgs_require = undef
  }

  Package {
    require => $_afspkgs_require,
  }

  case $facts['os']['release']['major'] {
    '6','7': { $afspkgs =  ['openafs', 'openafs-client', 'openafs-krb5', $afs_kmod_pkg, 'pam_krb5'] }
    default:   { $afspkgs =  ['openafs', 'openafs-client', 'openafs-krb5', $afs_kmod_pkg]}
  }

  package {$afspkgs:
    ensure  => present,
  }
  # Avoid that dkms-openafs might be installed as a possible dependency to openafs.
  Package[$afs_kmod_pkg] -> Package[openafs-client]
  Package[$afs_kmod_pkg] -> Package[openafs]

  if versioncmp($facts['os']['release']['major'],'8') >= 0 {

    $_aklog_unit_ensure = $aklog_unit ? {
      true    => 'present',
      default => 'absent',
    }
    package{'cern-aklog-systemd-user':
      ensure => $_aklog_unit_ensure,
    }

    $_pam_afs_session_ensure =  $pam_afs_session ? {
      true    => 'present',
      default => 'absent',
    }
    package{'pam_afs_session':
      ensure => $_pam_afs_session_ensure,
    }
  }

  package{'cern-wrappers':
    ensure => present,
  }

}

