# @summary Defaults for afs module
# @api private
class afs::params {

  $cachesize = lookup('afs_cachesize', Variant[String,Integer[0]], 'first', 524288)
  $memcachesize = lookup('afs_memcachesize', Variant[String,Integer[0]], 'first', 262144)
  $default_options = {
    chunksize => 18,
    daemons   => 10,
    dcache    => 60000,
    fakestat  => true,
    files     => 50000,
    nosettime => (versioncmp($facts['os']['release']['major'], '7') < 0), # i.e deprecated on CC7 and above
    stat      => 70000,
    volumes   => 512,
    memcache  => false,
    dynroot   => false,
    afsdb     => true,
  }
  $options   = lookup('afs_options',Hash,{'strategy' => 'deep', 'merge_hash_arrays' =>  true},{})
  $runserver = lookup('afs_runserver',Enum['on','off'],'first','off')
  $thiscell  = lookup('afs_thiscell',String[1], 'first', 'cern.ch')

  $_openafsversion = getvar(::openafsversion)
  if (versioncmp($facts['os']['release']['major'], '7') >= 0 or    # i.e any-tagged on CC7, CC8, non-CERN tagged elsewhere
    (($_openafsversion != undef) and
    ($_openafsversion != 'package openafs is not installed') and
    ($_openafsversion !~ /cern/))) {
    $is_upstream = true
  } else {
    $is_upstream = false  # i.e. SLC4/5/6, but only with 'cern' in the release
  }
  $enable_firewall = true
  $prefer_upstream_dkms = false  # choice between kmod-openafs (weak symbols) or dkms-openafs (recompiled on the machine)

  $aklog_unit = false
  $pam_afs_session = true
  $handle_cellservdb = true

}
