# @summary Control afs sserice
# @api private
class afs::service(
  $is_upstream = $afs::is_upstream,
) {

  # in openafs-1.6, the initscript for OpenAFS split into client &
  # server parts. The CERN OpenAFS version continued to use the old
  # 'afs' init script for the client on SLC5 and SLC6. Need to cope
  # with this.

  $afs_service = $is_upstream ? {
    true => 'openafs-client',
    default  => 'afs',
  }

  if versioncmp($facts['os']['release']['major'],'7') >= 0 {
    contain systemd::systemctl::daemon_reload
    Class['systemd::systemctl::daemon_reload'] -> Service['openafs-client']
  }

  service { 'openafs-client':  # keep the upstream name as 'generic'
    ensure     => running,
    name       => $afs_service,
    hasstatus  => false,    # not on SLC6 init script, unreliable on CC7 systemd
    pattern    => ' \[afsd\]$', # cache manager kernel thread, shows as '[afsd]' in "ps -ef"
    hasrestart => false,    # generally a very bad idea
    stop       => '/bin/false',
    enable     => true,
  }
}
